from django.db.models.signals import pre_delete
from django.dispatch import receiver
from arkindex.documents.models import Element, ElementPath


@receiver(pre_delete, sender=Element)
def pre_delete_handler(sender, instance, *args, **kwargs):
    assert isinstance(instance, Element)
    # Remove the instance's children
    for child in Element.objects.filter(paths__path__last=instance.id):
        instance.remove_child(child)
    # Remove instance from its parents
    parent_ids = [epath.path[-1] for epath in ElementPath.objects.filter(element=instance)]
    for parent in Element.objects.filter(id__in=parent_ids):
        parent.remove_child(instance)
