from django.urls import reverse
from rest_framework import status
from arkindex.project.tests import FixtureTestCase


class TestImageElements(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.img1 = cls.imgsrv.images.get(path='img1')

    def test_image_elements(self):
        response = self.client.get(reverse('api:image-elements', kwargs={'pk': self.img1.id}))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertListEqual(
            [element['name'] for element in data['results']],
            ['Volume 1, page 1r', 'Surface A', 'Surface B', 'Text line'],
        )

    def test_image_elements_type_filter(self):
        # Create an element of a different type with a zone
        cake_type = self.corpus.types.create(slug='cake', display_name='Cake')
        self.corpus.elements.create(
            type=cake_type,
            name='Quatre-quarts',
            zone=self.img1.zones.create(polygon=[(0, 0), (42, 42), (13, 37)]),
        )

        response = self.client.get(reverse('api:image-elements', kwargs={'pk': self.img1.id}) + '?type=cake')
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertListEqual(
            [element['name'] for element in data['results']],
            ['Quatre-quarts'],
        )

    def test_image_elements_folder_filter(self):
        # Add a zone on a folder
        vol = self.corpus.elements.get(name='Volume 1')
        self.assertTrue(vol.type.folder)
        vol.zone = self.img1.zones.create(polygon=[(0, 0), (0, 1), (1, 1)])
        vol.save()

        response = self.client.get(reverse('api:image-elements', kwargs={'pk': self.img1.id}) + '?folder')
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertListEqual(
            [element['name'] for element in data['results']],
            ['Volume 1'],
        )
